@@ -4,15 +4,10 @@ use 5.010001;
 use strict;
 use warnings;
 
-use Data::Dmp;
-
 # AUTHOR
-our $DATE = '2021-09-06'; # DATE
+our $DATE = '2021-09-07'; # DATE
 our $DIST = 'Data-Sah-Coerce-perl-To_date-From_str-natural'; # DIST
-our $VERSION = '0.012'; # VERSION
-
-# TMP
-our $time_zone = 'local';
+our $VERSION = '0.013'; # VERSION
 
 sub meta {
     +{
@@ -36,7 +31,7 @@ sub coerce {
     $res->{modules}{"DateTime::Format::Natural"} //= 0;
     $res->{expr_coerce} = join(
         "",
-        "do { my \$p = DateTime::Format::Natural->new(time_zone => ".dmp($time_zone)."); my \$datetime = \$p->parse_datetime($dt); ",
+        "do { my \$p = DateTime::Format::Natural->new(time_zone => 'local'); my \$datetime = \$p->parse_datetime($dt); ",
         "if (!\$p->success) { [\$p->error] } else { ",
         ($coerce_to eq 'float(epoch)' ? "[undef, \$datetime->epoch] " :
              $coerce_to eq 'Time::Moment' ? "[undef, Time::Moment->from_object(\$datetime)] " :
@@ -63,7 +58,7 @@ Data::Sah::Coerce::perl::To_date::From_str::natural_local - Coerce date from str
 
 =head1 VERSION
 
-This document describes version 0.012 of Data::Sah::Coerce::perl::To_date::From_str::natural_local (from Perl distribution Data-Sah-Coerce-perl-To_date-From_str-natural), released on 2021-09-06.
+This document describes version 0.013 of Data::Sah::Coerce::perl::To_date::From_str::natural_local (from Perl distribution Data-Sah-Coerce-perl-To_date-From_str-natural), released on 2021-09-07.
 
 =head1 SYNOPSIS
 
